package Bric::Biz::Asset::Business::Parts::Tile::Data;
###############################################################################

=head1 NAME

Bric::Biz::Asset::Business::Parts::Tile::Data - Deprecated; use Bric::Biz::Element::Field instead

=head1 VERSION

$LastChangedRevision$

=cut

require Bric; our $VERSION = Bric->VERSION;

=head1 DATE

$LastChangedDate: 2005-09-24 01:42:51 +0200 (Sat, 24 Sep 2005) $

=head1 DESCRIPTION

The functionality of this class has been moved to
L<Bric::Biz::Element::Field|Bric::Biz::Element::Field>. Please use that class,
instead.

=cut

use base 'Bric::Biz::Element::Field';

1;
__END__
